@@ -41,6 +41,10 @@
 
 lspec2pdf <- function(keep.img = TRUE, overwrite = FALSE, parallel = 1, path = NULL, pb = TRUE)
 {
+  # error message if jpeg package is not installed
+  if (!requireNamespace("jpeg",quietly = TRUE))
+    stop("must install 'jpeg' to use this function")
+  
   # set pb options 
   on.exit(pbapply::pboptions(type = .Options$pboptions$type), add = TRUE)
   
