@@ -133,10 +133,10 @@ resample_est <- function(X, samp.rate = 44.1, bit.depth = 16, sox = FALSE, avoid
   }   
 
   # fix attributes
-  attributes(X)$check.res$sample.rate <- samp.rate
-  attributes(X)$check.res$bits <- bit.depth
-  # attributes(X)$check.res$n.samples <- sapply(attributes(X)$check.res$sound.files, function(x) length(x@left)) 
-  attributes(X)$check.res$n.samples <- sapply(X$sound.files, function(x) length(attributes(X)$wave.objects[[which(names(attributes(X)$wave.objects) == x)]]@left)) 
+  attributes(X)$check.results$sample.rate <- samp.rate
+  attributes(X)$check.results$bits <- bit.depth
+  # attributes(X)$check.results$n.samples <- sapply(attributes(X)$check.results$sound.files, function(x) length(x@left)) 
+  attributes(X)$check.results$n.samples <- sapply(X$sound.files, function(x) length(attributes(X)$wave.objects[[which(names(attributes(X)$wave.objects) == x)]]@left)) 
   
   
   # replace with resampled waves
