@@ -6,7 +6,7 @@
 #' na.rm = FALSE, weight = NULL)
 #' @param X 'selection_table', 'extended_selection_table' (created 'by.song') or data frame with the following columns: 1) "sound.files": name of the .wav 
 #' files, 2) "selec": number of the selections, 3) "start": start time of selections, 4) "end": 
-#' end time of selections. The ouptut of \code{\link{manualoc}} or \code{\link{autodetec}} can 
+#' end time of selections. The output of \code{\link{manualoc}} or \code{\link{autodetec}} can 
 #' be used as the input data frame. Other data frames can be used as input, but must have at least the 4 columns mentioned above.
 #' @param song_colm Character string with the column name containing song labels. 
 #' It can be used to label any hierarchical level at which parameters need to be calculated (e.g. syllables, phrases).
@@ -21,7 +21,7 @@
 #' @param elm_fun Function to be applied to the sequence of elements composing a song. Default is \code{NULL}. Ignored if 'elm_colm' is not supplied. The name of the column containing the function's output is "elm_fun'.
 #' @param parallel Numeric. Controls whether parallel computing is applied.
 #' It specifies the number of cores to be used. Default is 1 (i.e. no parallel computing).
-#' @param sd Logical value indicating whether standard deviaton is also returned for
+#' @param sd Logical value indicating whether standard deviation is also returned for
 #' variables in which averages are reported. Default is \code{FALSE}.
 #' @param pb Logical argument to control progress bar and messages. Default is \code{TRUE}. 
 #' @param na.rm Logical value indicating whether 'NA' values should be ignored for calculations.
@@ -30,7 +30,7 @@
 #'  for more details.  Default is \code{NULL} (unweighted average).
 #' @return A data frame similar to the input 'X' data frame, but in this case each row corresponds to a single song. The data frame contains the mean or extreme
 #'  values for numeric columns for each song. Columns that will be averaged can be defined with
-#'  'mean_colm' (otherwhise all numeric columns are used). Columns can be 
+#'  'mean_colm' (otherwise all numeric columns are used). Columns can be 
 #'  weighted by other columns in the data set (e.g. duration, frequency range). In addition, the function returns the following song level parameters: 
 #' \itemize{
 #'    \item \code{elm.duration}: mean length of elements (in s)
@@ -221,15 +221,17 @@ song_param <- function(X = NULL, song_colm = "song", mean_colm = NULL, min_colm
     Z$start <- min(Y$start)
     Z$end <- max(Y$end)
     Z$elm.duration <- mean(Y$end - Y$start)
+    if (!is.null(Y$bottom.freq)){
     try(Z$bottom.freq <- min(Y$bottom.freq, na.rm = na.rm), silent = TRUE)
     try(Z$top.freq <- max(Y$top.freq, na.rm = na.rm), silent = TRUE)
     try(Z$freq.range <- Z$top.freq - Z$bottom.freq, silent = TRUE)
+      }
     Z$song.duration <- Z$end - Z$start
     Z$song.rate <- if(Z$num.elms == 1) NA else Z$num.elms / Z$song.duration
-    Z$gap.duration <- if(Z$num.elms == 1) NA else mean(Y$start[2:nrow(Y)] - Y$end[1:(nrow(Y) - 1)])
+    Z$gap.duration <- if(Z$num.elms == 1) NA else mean(Y$end[-nrow(Y)] - Y$start[-1])
     
     if(sd) {
-      Z$sd.gap.duration <- if(Z$num.elms == 1) NA else sd(Y$start[2:nrow(Y)] - Y$end[1:(nrow(Y) - 1)])
+      Z$sd.gap.duration <- if(Z$num.elms == 1) NA else sd(Y$end[-nrow(Y)] - Y$start[-1])
       Z$sd.elm.duration <- sd(Y$end - Y$start)
       }
     
